# SEI parameters

Example parameters for composite SEI on silicon/graphite. Both phases use the same values, from the paper

> Yang, X., Leng, Y., Zhang, G., Ge, S., Wang, C. (2017). Modeling of lithium plating induced aging of lithium-ion batteries: Transition from linear to nonlinear aging. Journal of Power Sources, 360, 28-40.
